@@ -5,7 +5,7 @@ func_caches = {}
 
 
 def cached(func):
-    @wraps
+    @wraps(func)
     def wrapper(*args, **kwargs):
         module = getattr(func, "__module__", "")
         name = getattr(func, "__name__", "")
