@@ -1,6 +1,7 @@
 import importlib
 import json
 import os
+import subprocess
 import urllib.parse
 import zipfile
 from getpass import getpass
@@ -123,6 +124,7 @@ def get_problem_id() -> int:
         problem_id = get_config_attr('problem_id')
         if problem_id is None:
             raise Exception('problem_id not found')
+        cache['problem_id'] = problem_id
 
     return cache['problem_id']
 
@@ -132,10 +134,17 @@ def get_file_type_id() -> int:
         file_type_id = get_config_attr('file_type_id')
         if file_type_id is None:
             raise Exception('file_type_id not found')
+        cache['file_type_id'] = file_type_id
 
     return cache['file_type_id']
 
 
+def compress(file_names: list, output_filename: str = "result.zip") -> None:
+    with zipfile.ZipFile(output_filename, mode="w") as zf:
+        for file_name in file_names:
+            zf.write('./' + file_name, file_name, compress_type=zipfile.ZIP_DEFLATED)
+
+
 def submit(*, submitting_file_name: str = 'result.zip', api: str = JUDGE_API):
     problem_id = get_problem_id()
     file_type_id = get_file_type_id()
@@ -157,8 +166,6 @@ def submit_files(file_names: list = None):
     if not file_names:
         raise Exception('No files selected to submit')
 
-    with zipfile.ZipFile("result.zip", mode="w") as zf:
-        for file_name in file_names:
-            zf.write('./' + file_name, file_name, compress_type=zipfile.ZIP_DEFLATED)
-
-    submit(submitting_file_name="result.zip")
+    output_filename = "result.zip"
+    compress(file_names, output_filename=output_filename)
+    submit(submitting_file_name=output_filename)
